==> libertem-0.2.0.tar.gz: libertem-0.2.0/client/src/dataset/actions.ts <==
import { ActionsUnion, createAction } from '../helpers/actionHelpers';
import { DatasetCreateParams, DatasetFormParams, DatasetState } from '../messages';

export enum ActionTypes {
    OPEN = 'DATASET_OPEN',
    CANCEL_OPEN = 'DATASET_CANCEL_OPEN',
    CREATE = 'DATASET_CREATE',
    CREATED = 'DATASET_CREATED',
    ERROR = 'DATASET_ERROR',
    DELETE = 'DATASET_DELETE',
    DELETED = 'DATASET_DELETED',
    DETECT = 'DATASET_DETECT',
    DETECTED = 'DATASET_DETECTED',
    DETECT_FAILED = 'DATASET_DETECT_FAILED',
}

export const Actions = {
    open: (path: string, initialParams?: DatasetFormParams) => createAction(ActionTypes.OPEN, { path, initialParams }),
    cancelOpen: () => createAction(ActionTypes.CANCEL_OPEN),
    create: (dataset: DatasetCreateParams) => createAction(ActionTypes.CREATE, { dataset }),
    created: (dataset: DatasetState) => createAction(ActionTypes.CREATED, { dataset }),
    error: (dataset: string, msg: string, timestamp: number, id: string) => createAction(ActionTypes.ERROR, { dataset, msg, timestamp, id }),
    delete: (dataset: string) => createAction(ActionTypes.DELETE, { dataset }),
    deleted: (dataset: string) => createAction(ActionTypes.DELETED, { dataset }),
    detect: (path: string) => createAction(ActionTypes.DETECT, { path }),
    detected: (path: string, params: DatasetFormParams) => createAction(ActionTypes.DETECTED, { path, params }),
    detectFailed: (path: string) => createAction(ActionTypes.DETECT_FAILED, { path }),
}

export type Actions = ActionsUnion<typeof Actions>;

==> libertem-0.7.1.tar.gz: libertem-0.7.1/client/src/dataset/actions.ts <==
import { ActionsUnion, createAction } from '../helpers/actionHelpers';
import { DatasetCreateParams, DatasetFormInfo, DatasetFormParams, DatasetState } from '../messages';

export enum ActionTypes {
    OPEN = 'DATASET_OPEN',
    CANCEL_OPEN = 'DATASET_CANCEL_OPEN',
    CREATE = 'DATASET_CREATE',
    CREATED = 'DATASET_CREATED',
    ERROR = 'DATASET_ERROR',
    DELETE = 'DATASET_DELETE',
    DELETED = 'DATASET_DELETED',
    DETECT = 'DATASET_DETECT',
    DETECTED = 'DATASET_DETECTED',
    DETECT_FAILED = 'DATASET_DETECT_FAILED',
}

export const Actions = {
    open: (path: string, cachedParams?: DatasetFormParams, detectedParams?: DatasetFormParams, detectedInfo?: DatasetFormInfo) => createAction(ActionTypes.OPEN, { path, cachedParams, detectedParams, detectedInfo }),
    cancelOpen: () => createAction(ActionTypes.CANCEL_OPEN),
    create: (dataset: DatasetCreateParams) => createAction(ActionTypes.CREATE, { dataset }),
    created: (dataset: DatasetState) => createAction(ActionTypes.CREATED, { dataset }),
    error: (dataset: string, msg: string, timestamp: number, id: string) => createAction(ActionTypes.ERROR, { dataset, msg, timestamp, id }),
    delete: (dataset: string) => createAction(ActionTypes.DELETE, { dataset }),
    deleted: (dataset: string) => createAction(ActionTypes.DELETED, { dataset }),
    detect: (path: string) => createAction(ActionTypes.DETECT, { path }),
    detected: (path: string, params: DatasetFormParams, info: DatasetFormInfo) => createAction(ActionTypes.DETECTED, { path, params, info }),
    detectFailed: (path: string) => createAction(ActionTypes.DETECT_FAILED, { path }),
}

export type Actions = ActionsUnion<typeof Actions>;
